@@ -17,7 +17,16 @@ REQUIREMENTS_IN = [  # this is actually ordered, as files depend on each other
     (path.parent / f"{path.stem}.in", path) for path in REQUIREMENTS.values()
 ]
 
-SUPPORTED = ["3.9", "3.10", "pypy3.10", "3.11", "3.12", "3.13", "3.13t"]
+SUPPORTED = [
+    "3.9",
+    "3.10",
+    "pypy3.10",
+    "3.11",
+    "pypy3.11",
+    "3.12",
+    "3.13",
+    "3.13t",
+]
 LATEST = "3.13"
 
 nox.options.default_venv_backend = "uv|virtualenv"
